/*= Rohde&Schwarz SMV Vector Signal Generator Include File ==================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/

#ifndef __RSSMV_HEADER
#define __RSSMV_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                           (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)

#define RSSMV_ERROR_INSTRUMENT_ERROR           (VI_ERROR_INSTR_OFFSET + 0xF0L)
#define RSSMV_ERROR_INVALID_CONFIGURATION      (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSSMV_ERROR_INSTRUMENT_OPTION          (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define RSSMV_ERROR_INSTRUMENT_NSUP_MODEL      (VI_ERROR_INSTR_OFFSET + 0xF3L)

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/

ViStatus _VI_FUNC rssmv_init (ViRsrc resourceName, ViBoolean IDQuery,
                ViBoolean resetDevice, ViPSession instrSession);
ViStatus _VI_FUNC rssmv_exOutAmpl (ViSession instrSession, ViReal64 frequency,
                ViReal64 offset, ViReal64 level,
                ViInt32 modulationSource,
                ViReal64 modulationDepth,
                ViReal64 modulationFrequency);
ViStatus _VI_FUNC rssmv_configRFFreq (ViSession instrSession,
                ViReal64 frequency, ViReal64 offset,
                ViReal64 multiplier);
ViStatus _VI_FUNC rssmv_setCWFreq (ViSession instrSession, ViReal64 frequency);
ViStatus _VI_FUNC rssmv_setRFFreqOffset (ViSession instrSession,
                ViReal64 offset);
ViStatus _VI_FUNC rssmv_setRFFreqMultiplier (ViSession instrSession,
                ViReal64 multiplier);
ViStatus _VI_FUNC rssmv_setCWFreqReset (ViSession instrSession,
                ViInt32 resetState);
ViStatus _VI_FUNC rssmv_setRFFreqMode (ViSession instrSession,
                ViInt32 operatingMode);
ViStatus _VI_FUNC rssmv_configRFFreqSweep (ViSession instrSession,
                ViInt32 sweepMode,
                ViReal64 startFrequency,
                ViReal64 stopFrequency,
                ViReal64 increment, ViReal64 dwellTime);
ViStatus _VI_FUNC rssmv_setRFFreqSweepMode (ViSession instrSession,
                ViInt32 sweepMode);
ViStatus _VI_FUNC rssmv_setRFStartFreq (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmv_setRFStopFreq (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmv_setRFFreqIncrement (ViSession instrSession,
                ViReal64 increment);
ViStatus _VI_FUNC rssmv_setRFFreqSweepDwellTime (ViSession instrSession,
                ViReal64 time);
ViStatus _VI_FUNC rssmv_setRFFreqSweepSpacing (ViSession instrSession,
                ViInt32 spacing);
ViStatus _VI_FUNC rssmv_setRFFreqSweepStep (ViSession instrSession,
                ViInt32 mode, ViReal64 step);
ViStatus _VI_FUNC rssmv_setRFSweepFreqManual (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmv_setRFCenterFreq (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmv_setRFSpanFreq (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmv_setRFExtDividerRange (ViSession instrSession,
                ViBoolean state);
ViStatus _VI_FUNC rssmv_setSweepBlankTime (ViSession instrSession,
                                           ViInt32 time);
ViStatus _VI_FUNC rssmv_configRFLevel (ViSession instrSession, ViReal64 level,
                ViReal64 offset, ViReal64 limit);
ViStatus _VI_FUNC rssmv_setRFLevel (ViSession instrSession, ViReal64 level);
ViStatus _VI_FUNC rssmv_setRFLevelOffset (ViSession instrSession,
                ViReal64 offset);
ViStatus _VI_FUNC rssmv_setRFLevelLimit (ViSession instrSession,
                ViReal64 limit);
ViStatus _VI_FUNC rssmv_setRFLevelMode (ViSession instrSession,
                ViInt32 operatingMode);
ViStatus _VI_FUNC rssmv_setRFLevelReset (ViSession instrSession,
                ViInt32 resetState);
ViStatus _VI_FUNC rssmv_configRFLevelSweep (ViSession instrSession,
                ViInt32 sweepMode, ViReal64 startLevel,
                ViReal64 stopLevel, ViReal64 step,
                ViReal64 dwellTime);
ViStatus _VI_FUNC rssmv_setRFLevelSweepMode (ViSession instrSession,
                ViInt32 sweepMode);
ViStatus _VI_FUNC rssmv_setRFStartLevel (ViSession instrSession,
                ViReal64 level);
ViStatus _VI_FUNC rssmv_setRFStopFreqLevel (ViSession instrSession,
                ViReal64 level);
ViStatus _VI_FUNC rssmv_setRFLevelIncrement (ViSession instrSession,
                ViReal64 increment);
ViStatus _VI_FUNC rssmv_setRFLevelSweepStep (ViSession instrSession,
                ViReal64 step);
ViStatus _VI_FUNC rssmv_setRFLevelSweepDwellTime (ViSession instrSession,
                ViReal64 time);
ViStatus _VI_FUNC rssmv_setRFLevelSweepManual (ViSession instrSession,
                ViReal64 level);
ViStatus _VI_FUNC rssmv_setRFLevelSweepSpacing (ViSession instrSession,
                ViInt32 spacing);
ViStatus _VI_FUNC rssmv_powerSweepPerformed (ViSession instrSession,
                                             ViInt32 sweep,
                                             ViChar _VI_FAR sweepPerformed[]);
ViStatus _VI_FUNC rssmv_ConfigureRFLevelCorr (ViSession instrSession,
                ViBoolean correctionState,
                ViString correctionListName,
                ViReal64 _VI_FAR frequencyPoints[],
                ViReal64 _VI_FAR powerPoints[],
                ViInt32 numberOfElements);
ViStatus _VI_FUNC rssmv_setRFLevelCorrState (ViSession instrSession,
                ViBoolean correctionState);
ViStatus _VI_FUNC rssmv_selCorrList (ViSession instrSession,
                ViString correctionListName);
ViStatus _VI_FUNC rssmv_deleteCorrList (ViSession instrSession,
                ViString correctionListName);
ViStatus _VI_FUNC rssmv_deleteAllCorrLists (ViSession instrSession);
ViStatus _VI_FUNC rssmv_getListOfCorrLists (ViSession instrSession,
                ViChar _VI_FAR listOfCorrectionLists[]);
ViStatus _VI_FUNC rssmv_setFreqToCorrList (ViSession instrSession,
                ViReal64 _VI_FAR frequency[],
                ViInt32 size);
ViStatus _VI_FUNC rssmv_setPowerToCorrList (ViSession instrSession,
                ViReal64 _VI_FAR power[], ViInt32 size);
ViStatus _VI_FUNC rssmv_getLevelCorrPoints (ViSession instrSession,
                ViPInt32 points);
ViStatus _VI_FUNC rssmv_getFreqCorrPoints (ViSession instrSession,
                                           ViPInt32 points);
ViStatus _VI_FUNC rssmv_getFreeCorrTables (ViSession instrSession,
                ViPInt32 freeSpace);
ViStatus _VI_FUNC rssmv_configRFOutput (ViSession instrSession,
                ViBoolean outputState,
                ViInt32 attenuationMode, ViReal64 reserved);
ViStatus _VI_FUNC rssmv_setRFOutputState (ViSession instrSession,
                ViBoolean outputState);
ViStatus _VI_FUNC rssmv_setRFAttMode (ViSession instrSession,
                ViInt32 attenuationMode);
ViStatus _VI_FUNC rssmv_setRFOutPowOnState (ViSession instrSession,
                ViInt32 outputState);
ViStatus _VI_FUNC rssmv_configAMModulation (ViSession instrSession,
                ViInt32 modulationSource,
                ViReal64 modulationDepth,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmv_configFMModulation (ViSession instrSession,
                ViInt32 modulationSource,
                ViReal64 deviation, ViReal64 frequency);
ViStatus _VI_FUNC rssmv_configPHMModulation (ViSession instrSession,
                ViInt32 modulationSource,
                ViReal64 deviation,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmv_configPulseModulation (ViSession instrSession,
                ViInt32 signalSource,
                ViInt32 polarity);
ViStatus _VI_FUNC rssmv_configStereoModulation (ViSession instrSession,
                ViReal64 MPXDeviation,
                ViInt32 source, ViInt32 stereoMode);
ViStatus _VI_FUNC rssmv_configVectorModulation (ViSession instrSession,
                ViBoolean impairmentState,
                ViReal64 leakage);
ViStatus _VI_FUNC rssmv_setAllModulationState (ViSession instrSession,
                                               ViBoolean allModulationState);
ViStatus _VI_FUNC rssmv_setAMState (ViSession instrSession,
                ViBoolean AMModState);
ViStatus _VI_FUNC rssmv_setAMDepth (ViSession instrSession, ViReal64 depth);
ViStatus _VI_FUNC rssmv_setAMFreq (ViSession instrSession, ViReal64 frequency);
ViStatus _VI_FUNC rssmv_setAMSource (ViSession instrSession,
                ViInt32 modulationSource);
ViStatus _VI_FUNC rssmv_setAMExtCoupling (ViSession instrSession,
                ViInt32 extInput, ViInt32 coupling);
ViStatus _VI_FUNC rssmv_setFMState (ViSession instrSession, ViBoolean modState);
ViStatus _VI_FUNC rssmv_setFMDeviation (ViSession instrSession,
                ViReal64 deviation);
ViStatus _VI_FUNC rssmv_setFMFreq (ViSession instrSession, ViReal64 frequency);
ViStatus _VI_FUNC rssmv_setFMSource (ViSession instrSession,
                ViInt32 modulationSource);
ViStatus _VI_FUNC rssmv_setFMExtCoup (ViSession instrSession, ViInt32 extInput,
                ViInt32 coupling);
ViStatus _VI_FUNC rssmv_setFMBand (ViSession instrSession, ViInt32 bandwidth);
ViStatus _VI_FUNC rssmv_setPHMState (ViSession instrSession,
                ViBoolean modState);
ViStatus _VI_FUNC rssmv_setPHMDeviation (ViSession instrSession,
                ViReal64 deviation);
ViStatus _VI_FUNC rssmv_setPHMFreq (ViSession instrSession, ViReal64 frequency);
ViStatus _VI_FUNC rssmv_setPHMSource (ViSession instrSession,
                ViInt32 modulationSource);
ViStatus _VI_FUNC rssmv_setPHMExtCoup (ViSession instrSession,
                ViInt32 coupling);
ViStatus _VI_FUNC rssmv_setPHMBand (ViSession instrSession, ViInt32 bandwidth);
ViStatus _VI_FUNC rssmv_setPMState (ViSession instrSession, ViBoolean modState);
ViStatus _VI_FUNC rssmv_setPMPolar (ViSession instrSession, ViInt32 polarity);
ViStatus _VI_FUNC rssmv_setPMSource (ViSession instrSession,
                ViInt32 modulationSource);
ViStatus _VI_FUNC rssmv_setStereoState (ViSession instrSession,
                ViBoolean modState);
ViStatus _VI_FUNC rssmv_setStereoDeviation (ViSession instrSession,
                ViReal64 deviation);
ViStatus _VI_FUNC rssmv_setStereoSource (ViSession instrSession,
                ViInt32 source);
ViStatus _VI_FUNC rssmv_setStereoMode (ViSession instrSession,
                ViInt32 stereoMode);
ViStatus _VI_FUNC rssmv_setStereoLFGenFrequency (ViSession instrSession,
                ViReal64 LFGenFrequency);
ViStatus _VI_FUNC rssmv_setStereoExtImpedance (ViSession instrSession,
                ViInt32 impedance);
ViStatus _VI_FUNC rssmv_setStereoPreemphasis (ViSession instrSession,
                ViInt32 preemphasis);
ViStatus _VI_FUNC rssmv_setStereoPilotState (ViSession instrSession,
                ViBoolean pilotState);
ViStatus _VI_FUNC rssmv_setStereoPilotDeviation (ViSession instrSession,
                ViReal64 pilotDeviation);
ViStatus _VI_FUNC rssmv_setStereoPilotPhase (ViSession instrSession,
                ViReal64 pilotPhase);
ViStatus _VI_FUNC rssmv_setStereoARIState (ViSession instrSession,
                ViBoolean ARIState);
ViStatus _VI_FUNC rssmv_setStereoARIDeviation (ViSession instrSession,
                ViReal64 ARIDeviation);
ViStatus _VI_FUNC rssmv_setStereoARIIdentification (ViSession instrSession,
                ViInt32 ARIIdentification);
ViStatus _VI_FUNC rssmv_setStereoARIBKCode (ViSession instrSession,
                ViInt32 BKCode);
ViStatus _VI_FUNC rssmv_setStereoRDSState (ViSession instrSession,
                ViBoolean RDSState);
ViStatus _VI_FUNC rssmv_setStereoRDSDeviation (ViSession instrSession,
                ViReal64 RDSDeviation);
ViStatus _VI_FUNC rssmv_setStereoRDSDataSet (ViSession instrSession,
                ViInt32 RDSDataSet);
ViStatus _VI_FUNC rssmv_setStereoRDSTrafficProgram (ViSession instrSession,
                ViBoolean RDSTrafficProgramState);
ViStatus _VI_FUNC rssmv_setStereoRDSTrafficAnnouncement (ViSession instrSession,
                ViBoolean RDSTrafficAnnouncementState);
ViStatus _VI_FUNC rssmv_writeRDSCommand (ViSession instrSession,
                ViString RDSCommand);
ViStatus _VI_FUNC rssmv_readRDSResponse (ViSession instrSession,
                ViString RDSQuery,
                ViInt32 numberBytesToRead,
                ViPInt32 numBytesRead,
                ViChar _VI_FAR readBuffer[]);
ViStatus _VI_FUNC rssmv_setVectorState (ViSession instrSession,
                ViBoolean modState);
ViStatus _VI_FUNC rssmv_setVectorImpairmentState (ViSession instrSession,
                ViBoolean impairmentState);
ViStatus _VI_FUNC rssmv_setVectorLeakage (ViSession instrSession,
                ViReal64 leakage);
ViStatus _VI_FUNC rssmv_setVectorImbalance (ViSession instrSession,
                ViReal64 imbalance);
ViStatus _VI_FUNC rssmv_setVectorQuadratureOffset (ViSession instrSession,
                ViReal64 quadratureOffset);
ViStatus _VI_FUNC rssmv_setVectorIQSwap (ViSession instrSession,
                ViBoolean IQSwap);
ViStatus _VI_FUNC rssmv_setALCState (ViSession instrSession,
                ViBoolean ALCState);
ViStatus _VI_FUNC rssmv_ALCSearch (ViSession instrSession,
                ViChar _VI_FAR searchResult[]);
ViStatus _VI_FUNC rssmv_configLFOutput (ViSession instrSession,
                ViBoolean LFOutputState, ViReal64 frequency,
                ViReal64 voltage);
ViStatus _VI_FUNC rssmv_setLFOutputState (ViSession instrSession,
                ViBoolean LFOutputState);
ViStatus _VI_FUNC rssmv_setLFCWFreq (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmv_setLFVoltage (ViSession instrSession, ViReal64 voltage);
ViStatus _VI_FUNC rssmv_setLFFreqMode (ViSession instrSession,
                ViInt32 operatingMode);
ViStatus _VI_FUNC rssmv_configLFSweep (ViSession instrSession,
                ViInt32 sweepMode, ViReal64 startFrequency,
                ViReal64 stopFrequency, ViReal64 step,
                ViReal64 dwellTime);
ViStatus _VI_FUNC rssmv_setLFSweepMode (ViSession instrSession,
                ViInt32 sweepMode);
ViStatus _VI_FUNC rssmv_setLFStartFreq (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmv_setLFStopFreq (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmv_setLFFreqMan (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmv_setLFSweepSpac (ViSession instrSession,
                ViInt32 spacing);
ViStatus _VI_FUNC rssmv_setLFSweepStep (ViSession instrSession, ViInt32 mode,
                ViReal64 step);
ViStatus _VI_FUNC rssmv_setLFSweepDwellTime (ViSession instrSession,
                ViReal64 time);
ViStatus _VI_FUNC rssmv_configPulseOutput (ViSession instrSession,
                ViInt32 polarity, ViReal64 pulsePeriod,
                ViReal64 pulseWidth,
                ViReal64 pulseDelay);
ViStatus _VI_FUNC rssmv_configVideoOutput (ViSession instrSession,
                ViInt32 reserved);
ViStatus _VI_FUNC rssmv_setPulseSource (ViSession instrSession, ViInt32 source);
ViStatus _VI_FUNC rssmv_setPulsePolarity (ViSession instrSession,
                ViInt32 polarity);
ViStatus _VI_FUNC rssmv_setPulsePeriod (ViSession instrSession,
                ViReal64 period);
ViStatus _VI_FUNC rssmv_setPulseWidth (ViSession instrSession, ViReal64 width);
ViStatus _VI_FUNC rssmv_setPulseDelay (ViSession instrSession, ViReal64 delay);
ViStatus _VI_FUNC rssmv_setDoublePulseState (ViSession instrSession,
                ViBoolean state);
ViStatus _VI_FUNC rssmv_setDoublePulseDelay (ViSession instrSession,
                ViReal64 delay);
ViStatus _VI_FUNC rssmv_configureRefOscilator (ViSession instrSession,
                ViBoolean refOscState,
                ViInt32 refSource,
                ViInt32 adjustValue);
ViStatus _VI_FUNC rssmv_setRFOscState (ViSession instrSession,
                ViBoolean refOscState);
ViStatus _VI_FUNC rssmv_setRefOscSource (ViSession instrSession,
                ViInt32 refSource);
ViStatus _VI_FUNC rssmv_setRefOscAdjVal (ViSession instrSession, ViInt32 value);
ViStatus _VI_FUNC rssmv_setRefOscRLoop (ViSession instrSession,
                ViInt32 refLoop);
ViStatus _VI_FUNC rssmv_setRefPhaseState (ViSession instrSession,
                ViBoolean refPhaseState);
ViStatus _VI_FUNC rssmv_setRefPhase (ViSession instrSession,
                ViReal64 phaseValue);
ViStatus _VI_FUNC rssmv_zeroRefPhase (ViSession instrSession);
ViStatus _VI_FUNC rssmv_setSweepTrigSource (ViSession instrSession,
                ViInt32 generator,
                ViInt32 triggerSource);
ViStatus _VI_FUNC rssmv_setPulseTrigSource (ViSession instrSession,
                ViInt32 triggerSource);
ViStatus _VI_FUNC rssmv_setPulseTrigSlope (ViSession instrSession,
                ViInt32 triggerSlope);
ViStatus _VI_FUNC rssmv_setPulseTrigPolarity (ViSession instrSession,
                ViInt32 triggerPolarity);
ViStatus _VI_FUNC rssmv_setLevCalState (ViSession instrSession,
                ViBoolean levelCalibration);
ViStatus _VI_FUNC rssmv_setAttCorrState (ViSession instrSession,
                ViBoolean correction);
ViStatus _VI_FUNC rssmv_getRefOscCalVal (ViSession instrSession,
                ViPInt32 value);
ViStatus _VI_FUNC rssmv_storeRefOscCalVal (ViSession instrSession);
ViStatus _VI_FUNC rssmv_SendTrigger (ViSession instrSession, ViInt32 generator,
                ViInt32 systemToTrigger);
ViStatus _VI_FUNC rssmv_abortTrigger (ViSession instrSession,
                ViInt32 systemToAbort);
ViStatus _VI_FUNC rssmv_utilCalibration (ViSession instrSession,
                ViInt32 toCalibrate, ViInt32 timeout,
                ViChar _VI_FAR calibrationResults[]);
ViStatus _VI_FUNC rssmv_utilSystemKeylock (ViSession instrSession,
                                           ViBoolean lockout);
ViStatus _VI_FUNC rssmv_utilRecallSetup (ViSession instrSession,
                ViInt32 registerNo);
ViStatus _VI_FUNC rssmv_utilSaveSetup (ViSession instrSession,
                ViInt32 registerNo);
ViStatus _VI_FUNC rssmv_utilGetFreeSett (ViSession instrSession,
                ViPInt32 value);
ViStatus _VI_FUNC rssmv_utilSetReg (ViSession instrSession,
                ViInt32 registerName, ViInt32 value);
ViStatus _VI_FUNC rssmv_utilGetReg (ViSession instrSession,
                ViInt32 registerName, ViPInt32 value);
ViStatus _VI_FUNC rssmv_utilSetDisplayMode (ViSession instrSession,
                ViInt32 parameter, ViBoolean state);
ViStatus _VI_FUNC rssmv_utilSetDisplayUpdate (ViSession instrSession,
                ViBoolean displayUpdate);
ViStatus _VI_FUNC rssmv_utilSetGPIBAddr (ViSession instrSession,
                ViInt32 address);
ViStatus _VI_FUNC rssmv_utilConfigureRS232 (ViSession instrSession,
                ViInt32 baudRate, ViInt32 dataBits,
                ViInt32 stopBits,
                ViInt32 hardwareHandshake,
                ViInt32 softwareHandshake,
                ViInt32 parity);
ViStatus _VI_FUNC rssmv_utilTest (ViSession instrSession, ViInt32 toTest,
                ViChar _VI_FAR testResults[]);
ViStatus _VI_FUNC rssmv_FlushErrorQueue (ViSession instrSession);
ViStatus _VI_FUNC rssmv_errorCheckState (ViSession instrSession,
                ViBoolean stateChecking);
ViStatus _VI_FUNC rssmv_writeInstrData (ViSession instrSession,
                ViString writeBuffer);
ViStatus _VI_FUNC rssmv_readInstrData (ViSession instrSession,
                ViInt32 numberBytesToRead,
                ViChar _VI_FAR readBuffer[],
                ViPInt32 numBytesRead);
ViStatus _VI_FUNC rssmv_reset (ViSession instrSession);
ViStatus _VI_FUNC rssmv_self_test (ViSession instrSession,
                ViPInt16 selfTestResult,
                ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rssmv_error_query (ViSession instrSession, ViPInt32 errorCode,
                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssmv_error_message (ViSession instrSession,
                ViStatus statusCode,
                ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rssmv_revision_query (ViSession instrSession,
                ViChar _VI_FAR instrumentDriverRevision[],
                ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rssmv_close (ViSession instrSession);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
